.. :changelog:

History
-------


0.1.3 (2018-10-16)
++++++++++++++++++

* Minor bug fix


0.1.2 (2018-10-16)
++++++++++++++++++

* Colors module refactored and additional tests written
* Documentation updated
* Added support for Python 3.4+


0.1.1 (2018-10-15)
++++++++++++++++++

* Documentation added


0.1.0 (2018-10-15)
++++++++++++++++++

* First release on PyPI.
* Colors module providing inforcehub brand colors
